Improve this doc View Source

The `$animateProvider` allows developers to register JavaScript animation event handlers directly inside of a module. When an animation is triggered, the $animate service will query the $animate service to find any animations that match the provided name value.

Requires the `ngAnimate` module to be installed.

Please visit the `ngAnimate` module overview page learn more about how to use animations in your application.